@@ -44,3 +44,10 @@ test_that(
   }
 )
 
+test_that(
+  "default type is character", {
+
+    expect_type(cast_to_type(1, NULL), "character")
+
+  }
+)
